summaryrefslogtreecommitdiff
path: root/town_cmd.c
diff options
context:
space:
mode:
Diffstat (limited to 'town_cmd.c')
-rw-r--r--town_cmd.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/town_cmd.c b/town_cmd.c
index bcffa01c0..9c00cf25a 100644
--- a/town_cmd.c
+++ b/town_cmd.c
@@ -612,15 +612,16 @@ static void GrowTownInTile(TileIndex* tile_ptr, RoadBits mask, int block, Town*
} else {
int i;
- // Reached a tunnel? Then continue at the other side of it.
- if (IsTunnelTile(tile) && GetTunnelTransportType(tile) == TRANSPORT_ROAD) {
- *tile_ptr = GetOtherTunnelEnd(tile);
+ // Reached a tunnel/bridge? Then continue at the other side of it.
+ if (IsTileType(tile, MP_TUNNELBRIDGE)) {
+ if (IsTunnel(tile) && GetTunnelTransportType(tile) == TRANSPORT_ROAD) {
+ *tile_ptr = GetOtherTunnelEnd(tile);
+ } else if (IsBridge(tile) && GetBridgeTransportType(tile) == TRANSPORT_ROAD) {
+ *tile_ptr = GetOtherBridgeEnd(tile);
+ }
return;
}
- // For any other kind of tunnel/bridge, bail out.
- if (IsTileType(tile, MP_TUNNELBRIDGE)) return;
-
// Possibly extend the road in a direction.
// Randomize a direction and if it has a road, bail out.
i = GB(Random(), 0, 2);